#version 150
#moj_import <fog.glsl>
#moj_import <light.glsl>
#define SPEED 50
#define WIDTH 128
#define HEIGHT 64
const vec4 armorPixel = vec4(1);
const ivec2 ipc = ivec2(0, 1);
uniform sampler2D Sampler0;
uniform vec4 ColorModulator;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;
uniform float GameTime;
uniform vec3 Light0_Direction;
uniform vec3 Light1_Direction;
in float vertexDistance;
in vec4 vertexColor;
in vec2 texCoord0;
in vec2 texCoord1;
in vec4 normal;
flat in vec4 tint;
flat in vec3 vNormal;
flat in vec4 texel;
out vec4 fragColor;
void main() {
	vec4 color;
	if (texelFetch(Sampler0, ipc, 0) == armorPixel) {
		ivec2 atlasSize = textureSize(Sampler0, 0);
		int amountW = atlasSize.x / WIDTH;
		int amountH = atlasSize.y / HEIGHT;
		vec2 coords = vec2(texCoord0.x / amountW, texCoord0.y / amountH);
		vec4 textureProperties = vec4(0);
		vec4 customColor = vec4(0);
		float h_offset = 1.0 / amountW;
		float v_offset = 1.0 / amountH;    
		vec2 nextFrame = vec2(0);
		float interpolClock = 0;
		vec4 vtc = vertexColor;
		int x = 0;
		int y = 0;
		while (y < amountH) {
			customColor = texelFetch(Sampler0, ivec2(WIDTH * x, HEIGHT * y), 0);
			if (tint == customColor) {
				coords.x += (h_offset * x + 1);
				coords.y += (v_offset * y + 1);  
				textureProperties = texelFetch(Sampler0, ivec2(WIDTH * x + 2, HEIGHT * y), 0);
				textureProperties.rgb *= textureProperties.a * 255;					      
				vec4 animInfo = texelFetch(Sampler0, ivec2(WIDTH * x + 1, HEIGHT * y), 0);
				animInfo.rgb *= animInfo.a * 255;
				if (animInfo.r > 1.0) {
					float p = GameTime * SPEED * animInfo.g;
					float timer = floor(mod(p, animInfo.r));
					if (animInfo.b > 0) interpolClock = fract(p);
					nextFrame = coords;
					coords.y += v_offset * timer;
					nextFrame.y = mod(coords.y + 1, animInfo.r);
				}
				break;
			}
			if (++x > 2) {
				x++;
				if (x >= amountW) {
					x = 0;
					y++;
				}
			}
		}
		if (y < amountH) {
			if (textureProperties.g == 1) {
				if (textureProperties.r > 1) {
					vtc = tint;
				} else if (textureProperties.r == 1) {
					if (texture(Sampler0, vec2(coords.x + h_offset, coords.y)).a != 0) {
						vtc = tint * texture(Sampler0, vec2(coords.x + h_offset, coords.y)).a;
					}					
				}
			} else if (textureProperties.g == 0) {
				if (textureProperties.r > 1) {
					vtc = vec4(1);
				} else if (textureProperties.r == 1) {
					if (texture(Sampler0, vec2(coords.x + h_offset, coords.y)).a != 0) {
						vtc = vec4(1) * texture(Sampler0, vec2(coords.x + h_offset, coords.y)).a;
					} else {
						vtc = minecraft_mix_light(Light0_Direction, Light1_Direction, vNormal, vec4(1)) * texel;
					}
				} else {
					vtc = minecraft_mix_light(Light0_Direction, Light1_Direction, vNormal, vec4(1)) * texel;
				}
			} else {
				vtc = minecraft_mix_light(Light0_Direction, Light1_Direction, vNormal, vec4(1)) * texel;
			}
			color = mix(texture(Sampler0, coords), texture(Sampler0, nextFrame), interpolClock) * vtc * ColorModulator;			
		} else {
			color = texture(Sampler0, coords) * vertexColor * ColorModulator;
		}
	} else {
		color = texture(Sampler0, texCoord0) * vertexColor * ColorModulator;
	}
	if (color.a < 0.1) {
		discard;
	}
	fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
}
